@@ -2,7 +2,7 @@
 /*
  * Hitori
  * Copyright (C) Philip Withnall 2007-2009 <philip@tecnocode.co.uk>
- * 
+ *
  * Hitori is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
@@ -46,7 +46,6 @@ static void new_game_cb (GSimpleAction *action, GVariant *parameter, gpointer us
 static void hint_cb (GSimpleAction *action, GVariant *parameter, gpointer user_data);
 static void undo_cb (GSimpleAction *action, GVariant *parameter, gpointer user_data);
 static void redo_cb (GSimpleAction *action, GVariant *parameter, gpointer user_data);
-static void quit_cb (GSimpleAction *action, GVariant *parameter, gpointer user_data);
 static void help_cb (GSimpleAction *action, GVariant *parameter, gpointer user_data);
 static void about_cb (GSimpleAction *action, GVariant *parameter, gpointer user_data);
 static void board_size_change_cb (GObject *object, GParamSpec *pspec, gpointer user_data);
@@ -55,7 +54,6 @@ static GActionEntry app_entries[] = {
 	{ "new-game", new_game_cb, NULL, NULL, NULL },
 	{ "about", about_cb, NULL, NULL, NULL },
 	{ "help", help_cb, NULL, NULL, NULL },
-	{ "quit", quit_cb, NULL, NULL, NULL },
 };
 
 static GActionEntry win_entries[] = {
@@ -134,7 +132,7 @@ lookup_color (GtkStyleContext *style_context, const gchar *name, GdkRGBA *result
 }
 
 static void
-draw_cell (Hitori *hitori, GtkStyleContext *style_context, cairo_t *cr, gfloat cell_size, gdouble x_pos, gdouble y_pos,
+draw_cell (Hitori *hitori, GtkStyleContext *style_context, cairo_t *cr, gdouble cell_size, gdouble x_pos, gdouble y_pos,
            HitoriVector iter)
 {
 	gchar *text;
@@ -307,7 +305,7 @@ hitori_draw_cb (GtkWidget *drawing_area, cairo_t *cr, Hitori *hitori)
 
 	/* Draw a hint if applicable */
 	if (hitori->hint_status % 2 == 1) {
-		gfloat line_width = BORDER_LEFT * 2.5;
+		gdouble line_width = BORDER_LEFT * 2.5;
 		GdkRGBA colour;
 		lookup_color (style_context, "hint-border-color", &colour);
 		gdk_cairo_set_source_rgba (cr, &colour);
@@ -621,13 +619,6 @@ redo_cb (GSimpleAction *action, GVariant *parameter, gpointer user_data)
 	gtk_widget_queue_draw (self->drawing_area);
 }
 
-static void
-quit_cb (GSimpleAction *action, GVariant *parameters, gpointer user_data)
-{
-	HitoriApplication *self = HITORI_APPLICATION (user_data);
-	hitori_quit (self);
-}
-
 static void
 help_cb (GSimpleAction *action, GVariant *parameters, gpointer user_data)
 {
